@@ -49,6 +49,7 @@
 #include <errno.h>
 #include <signal.h>
 #include "nilfs.h"
+#include "compat.h"	/* getprogname() */
 #include "parser.h"
 #include "util.h"
 
@@ -66,12 +67,12 @@ static const struct option long_option[] = {
 };
 
 #define CHCP_USAGE	\
-	"Usage: %s [OPTION]... " CHCP_MODE_CP "|" CHCP_MODE_SS" [DEVICE] CNO...\n"	\
+	"Usage: %s [OPTION]... " CHCP_MODE_CP "|" CHCP_MODE_SS" [DEVICE|NODE] CNO...\n"	\
 	"  -h, --help\t\tdisplay this help and exit\n"			\
 	"  -V, --version\t\tdisplay version and exit\n"
 #else	/* !_GNU_SOURCE */
 #define CHCP_USAGE	\
-	"Usage: %s [option]... " CHCP_MODE_CP "|" CHCP_MODE_SS " [device] cno...\n"
+	"Usage: %s [option]... " CHCP_MODE_CP "|" CHCP_MODE_SS " [device|node] cno...\n"
 #endif	/* _GNU_SOURCE */
 
 
@@ -79,16 +80,13 @@ int main(int argc, char *argv[])
 {
 	struct nilfs *nilfs;
 	nilfs_cno_t cno;
-	char *dev, *modestr, *progname, *endptr, *last;
+	char *dev, *modestr, *endptr;
 	int c, mode, status, ret;
 #ifdef _GNU_SOURCE
 	int option_index;
 #endif	/* _GNU_SOURCE */
 	sigset_t sigset, oldset;
 
-	last = strrchr(argv[0], '/');
-	progname = last ? last + 1 : argv[0];
-
 #ifdef _GNU_SOURCE
 	while ((c = getopt_long(argc, argv, "hV",
 				long_option, &option_index)) >= 0) {
@@ -98,10 +96,10 @@ int main(int argc, char *argv[])
 
 		switch (c) {
 		case 'h':
-			fprintf(stderr, CHCP_USAGE, progname);
+			printf(CHCP_USAGE, getprogname());
 			exit(EXIT_SUCCESS);
 		case 'V':
-			printf("%s (%s %s)\n", progname, PACKAGE,
+			printf("%s (%s %s)\n", getprogname(), PACKAGE,
 			       PACKAGE_VERSION);
 			exit(EXIT_SUCCESS);
 		default:
@@ -130,7 +128,8 @@ int main(int argc, char *argv[])
 	else
 		errx(EXIT_FAILURE, "%s: invalid checkpoint mode", modestr);
 
-	nilfs = nilfs_open(dev, NULL, NILFS_OPEN_RDWR | NILFS_OPEN_GCLK);
+	nilfs = nilfs_open(dev, NULL, (NILFS_OPEN_RDWR | NILFS_OPEN_GCLK |
+				       NILFS_OPEN_SRCHDEV));
 	if (nilfs == NULL)
 		err(EXIT_FAILURE, "cannot open NILFS on %s", dev ? : "device");
 
@@ -183,8 +182,7 @@ int main(int argc, char *argv[])
 		ret = nilfs_change_cpmode(nilfs, cno, mode);
 		if (unlikely(ret < 0)) {
 			if (errno == ENOENT)
-				warnx("%llu: no checkpoint",
-				      (unsigned long long)cno);
+				warnx("%" PRIcno ": no checkpoint", cno);
 			else
 				warn(NULL);
 			status = EXIT_FAILURE;
